@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,11 +21,12 @@ void FilterNameWidgetTest::shouldHaveDefaultValues()
     MessageList::Core::FilterNameWidget w;
     auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->contentsMargins(), {});
+    QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
     auto mName = w.findChild<QLineEdit *>(QStringLiteral("mName"));
     QVERIFY(mName);
     QVERIFY(mName->text().isEmpty());
+    QVERIFY(mName->isClearButtonEnabled());
 
     auto mIconButton = w.findChild<KIconButton *>(QStringLiteral("mIconButton"));
     QVERIFY(mIconButton);
