@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,11 +8,10 @@
 #pragma once
 
 #include "messagelist_export.h"
-#include <Akonadi/KMime/MessageStatus>
+#include <Akonadi/MessageStatus>
 #include <QWidget>
 
 class QComboBox;
-class QToolButton;
 namespace MessageList
 {
 namespace Core
@@ -69,7 +68,7 @@ Q_SIGNALS:
     void statusButtonsClicked();
     void forceLostFocus();
     void saveFilter();
-    void activateFilter(Filter *f);
+    void activateFilter(MessageList::Core::Filter *f);
 
 protected:
     bool eventFilter(QObject *object, QEvent *e) override;
