@@ -4,9 +4,9 @@
     This file is part of KMail, the KDE mail client.
     SPDX-FileCopyrightText: 2003 Marc Mutz <mutz@kde.org>
 
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "headerstrategy.h"
@@ -15,22 +15,18 @@
 // HeaderStrategy abstract base:
 //
 using namespace MessageViewer;
-HeaderStrategy::HeaderStrategy()
-{
-}
+HeaderStrategy::HeaderStrategy() = default;
 
-HeaderStrategy::~HeaderStrategy()
-{
-}
+HeaderStrategy::~HeaderStrategy() = default;
 
 QStringList HeaderStrategy::headersToDisplay() const
 {
-    return QStringList();
+    return {};
 }
 
 QStringList HeaderStrategy::headersToHide() const
 {
-    return QStringList();
+    return {};
 }
 
 bool HeaderStrategy::showHeader(const QString &header) const
