@@ -1,36 +1,36 @@
 /*
-   Copyright (c) 2017 Volker Krause <vkrause@kde.org>
+   SPDX-FileCopyrightText: 2017 Volker Krause <vkrause@kde.org>
 
-   This library is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Library General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or (at your
-   option) any later version.
-
-   This library is distributed in the hope that it will be useful, but WITHOUT
-   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-   License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-   02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "grantleeextension.h"
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/exception.h>
 #include <grantlee/parser.h>
+#else
+#include <KTextTemplate/exception.h>
+#include <KTextTemplate/parser.h>
+#endif
 
 using namespace MessageViewer;
 
 CallbackTag::CallbackTag(const QString &name, QObject *parent)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : Grantlee::Node(parent)
+#else
+    : KTextTemplate::Node(parent)
+#endif
     , m_name(name)
 {
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void CallbackTag::render(Grantlee::OutputStream *stream, Grantlee::Context *context) const
+#else
+void CallbackTag::render(KTextTemplate::OutputStream *stream, KTextTemplate::Context *context) const
+#endif
 {
     auto cb = context->lookup(m_name).value<GrantleeCallback>();
     if (cb) {
@@ -38,13 +38,13 @@ void CallbackTag::render(Grantlee::OutputStream *stream, Grantlee::Context *cont
     }
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 Grantlee::Node *CallbackTagFactory::getNode(const QString &tagContent, Grantlee::Parser *parser) const
-{
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    auto expr = tagContent.split(QLatin1Char(' '), QString::SkipEmptyParts);
 #else
-    auto expr = tagContent.split(QLatin1Char(' '), Qt::SkipEmptyParts);
+KTextTemplate::Node *CallbackTagFactory::getNode(const QString &tagContent, KTextTemplate::Parser *parser) const
 #endif
+{
+    auto expr = tagContent.split(QLatin1Char(' '), Qt::SkipEmptyParts);
     if (expr.size() != 2) {
         return nullptr;
     }
@@ -57,10 +57,18 @@ GrantleeTagLibrary::GrantleeTagLibrary(QObject *parent)
 {
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 QHash<QString, Grantlee::AbstractNodeFactory *> GrantleeTagLibrary::nodeFactories(const QString &name)
+#else
+QHash<QString, KTextTemplate::AbstractNodeFactory *> GrantleeTagLibrary::nodeFactories(const QString &name)
+#endif
 {
-    Q_UNUSED(name);
+    Q_UNUSED(name)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QHash<QString, Grantlee::AbstractNodeFactory *> nodeFactories;
+#else
+    QHash<QString, KTextTemplate::AbstractNodeFactory *> nodeFactories;
+#endif
     nodeFactories.insert(QStringLiteral("callback"), new CallbackTagFactory());
     return nodeFactories;
 }
