@@ -16,19 +16,20 @@
 #include <WebEngineViewer/InterceptorManager>
 #include <WebEngineViewer/WebEngineManageScript>
 
-#include "scamdetection/scamcheckshorturl.h"
 #include "scamdetection/scamdetectionwebengine.h"
 #include <QContextMenuEvent>
 #include <QWebEngineProfile>
 #include <WebEngineViewer/WebHitTest>
 
+#include <QPainter>
 #include <QPrinter>
 #include <QWebEngineUrlScheme>
 
 #include <WebEngineViewer/WebHitTestResult>
 
 using namespace MessageViewer;
-template<typename Arg, typename R, typename C> struct InvokeWrapper {
+template<typename Arg, typename R, typename C>
+struct InvokeWrapper {
     R *receiver;
     void (C::*memberFunction)(Arg);
     void operator()(Arg result)
