@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -39,10 +39,7 @@ PrintingSettings::PrintingSettings(QWidget *parent)
     connect(d->mPrintingUi->alwaysShowEncryptionSignatureDetail, &QCheckBox::toggled, this, &PrintingSettings::changed);
 }
 
-PrintingSettings::~PrintingSettings()
-{
-    delete d;
-}
+PrintingSettings::~PrintingSettings() = default;
 
 void PrintingSettings::save()
 {
