@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_BODYFORAMATTER_TEXTHTML_H
-#define MIMETREEPARSER_BODYFORAMATTER_TEXTHTML_H
+#pragma once
 
 #include "interfaces/bodypart.h"
 #include "interfaces/bodypartformatter.h"
@@ -21,5 +20,3 @@ public:
     static const Interface::BodyPartFormatter *create();
 };
 }
-
-#endif
