@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,9 +9,7 @@
 
 using namespace WebEngineViewer;
 
-UpdateDataBaseInfo::UpdateDataBaseInfo()
-{
-}
+UpdateDataBaseInfo::UpdateDataBaseInfo() = default;
 
 bool UpdateDataBaseInfo::isValid() const
 {
