@@ -14,7 +14,8 @@
 #include <QTextEdit>
 #include <QWebEngineSettings>
 
-template<typename Arg, typename R, typename C> struct InvokeWrapper {
+template<typename Arg, typename R, typename C>
+struct InvokeWrapper {
     R *receiver;
     void (C::*memberFunction)(Arg);
     void operator()(Arg result)
@@ -98,7 +99,9 @@ void TestWebEngineScript::slotExecuteScript()
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     auto testWebEngine = new TestWebEngineScript;
     testWebEngine->show();
     const int ret = app.exec();
