@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef NETWORKPLUGINURLINTERCEPTORCONFIGUREWIDGET_H
-#define NETWORKPLUGINURLINTERCEPTORCONFIGUREWIDGET_H
+#pragma once
 
 #include "webengineviewer_export.h"
 #include <QWidget>
@@ -33,4 +32,3 @@ Q_SIGNALS:
     void configureChanged();
 };
 }
-#endif // NETWORKPLUGINURLINTERCEPTORCONFIGUREWIDGET_H
